@@ -198,7 +198,7 @@ spawn_passwd (PasswordDialog *pdialog, GError **error)
 								   &my_stderr,						/* Stderr */
 								   error)) {					/* GError */
 
-		/* An error occured */
+		/* An error occurred */
 		free_passwd_resources (pdialog);
 
 		return FALSE;
@@ -428,7 +428,6 @@ io_watch_stdout (GIOChannel *source, GIOCondition condition, PasswordDialog *pdi
 	GError		*error = NULL;
 
 	gchar		*msg = NULL;		/* Status error message */
-	GtkBuilder	*dialog = NULL;
 
 	gboolean	reinit = FALSE;
 
@@ -437,8 +436,6 @@ io_watch_stdout (GIOChannel *source, GIOCondition condition, PasswordDialog *pdi
 		str = g_string_new ("");
 	}
 
-	dialog = pdialog->ui;
-
 	if (g_io_channel_read_chars (source, buf, BUFSIZE, &bytes_read, &error) != G_IO_STATUS_NORMAL) {
 		g_warning ("IO Channel read error: %s", error->message);
 		g_error_free (error);
@@ -566,7 +563,7 @@ io_watch_stdout (GIOChannel *source, GIOCondition condition, PasswordDialog *pdi
 				reinit = TRUE;
 
 				if (msg != NULL) {
-					/* An error occured! */
+					/* An error occurred! */
 					passdlg_set_status (pdialog, msg);
 					g_free (msg);
 
@@ -688,7 +685,11 @@ passdlg_set_busy (PasswordDialog *pdialog, gboolean busy)
 	gdk_display_flush (display);
 
 	if (busy) {
+#if GTK_CHECK_VERSION (3, 0, 0)
+		g_object_unref (cursor);
+#else
 		gdk_cursor_unref (cursor);
+#endif
 	}
 
 	/* Disable/Enable UI */
@@ -873,12 +874,9 @@ passdlg_authenticate (GtkButton *button, PasswordDialog *pdialog)
 static guint
 passdlg_validate_passwords (PasswordDialog *pdialog)
 {
-	GtkBuilder	*dialog = NULL;
 	const gchar	*new_password, *retyped_password;
 	glong			nlen, rlen;
 
-	dialog = pdialog->ui;
-
 	new_password = gtk_entry_get_text (pdialog->new_password);
 	retyped_password = gtk_entry_get_text (pdialog->retyped_password);
 
@@ -964,7 +962,7 @@ passdlg_process_response (PasswordDialog *pdialog, gint response_id)
 		/* Set busy as this can be a long process */
 		passdlg_set_busy (pdialog, TRUE);
 
-		/* Stop passwd if an error occured and it is still running */
+		/* Stop passwd if an error occurred and it is still running */
 		if (pdialog->backend_state == PASSWD_STATE_ERR) {
 
 			/* Stop passwd, free resources */
@@ -972,7 +970,7 @@ passdlg_process_response (PasswordDialog *pdialog, gint response_id)
 		}
 
 		/* Check that the backend is still running, or that an error
-		 * hass occured but it has not yet exited */
+		 * has occurred but it has not yet exited */
 		if (pdialog->backend_pid == -1) {
 			/* If it is not, re-run authentication */
 
