@@ -591,7 +591,11 @@ egg_cell_renderer_keys_start_editing (GtkCellRenderer      *cell,
                              (void**) &keys->edit_widget);
 
   label = gtk_label_new (NULL);
+#if GTK_CHECK_VERSION (3, 16, 0)
+  gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+#else
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
 
   gtk_widget_modify_bg (eventbox, GTK_STATE_NORMAL,
                         &gtk_widget_get_style (widget)->bg[GTK_STATE_SELECTED]);
