@@ -274,7 +274,6 @@ application_tile_setup (ApplicationTile *this)
 
 	const gchar *comment;
 
-	const gchar *key;
 	gchar *markup;
 	gchar *str;
 
@@ -403,7 +402,11 @@ create_header (const gchar *name)
 
 	header = gtk_label_new (name);
 	gtk_label_set_line_wrap (GTK_LABEL (header), TRUE);
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (header), 0.0);
+#else
 	gtk_misc_set_alignment (GTK_MISC (header), 0.0, 0.5);
+#endif
 
 	g_signal_connect (
 		G_OBJECT (header),
@@ -422,7 +425,11 @@ create_subheader (const gchar *desc)
 
 	subheader = gtk_label_new (desc);
 	gtk_label_set_ellipsize (GTK_LABEL (subheader), PANGO_ELLIPSIZE_END);
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (subheader), 0.0);
+#else
 	gtk_misc_set_alignment (GTK_MISC (subheader), 0.0, 0.5);
+#endif
 	gtk_widget_modify_fg (
 		subheader,
 		GTK_STATE_NORMAL,
